@@ -2,8 +2,10 @@
 #' @export
 get_coef.brmultinom <- function(model, ...) {
     out <- insight::get_parameters(model)
-    out <- stats::setNames(out$Estimate,
-                           sprintf("%s:%s", out$Response, out$Parameter))
+    out <- stats::setNames(
+        out$Estimate,
+        sprintf("%s:%s", out$Response, out$Parameter)
+    )
     return(out)
 }
 
